BP/RP (often shortened as XP) spectra became available for the first time in Gaia Data Release 3 (DR3). In their first release, only source mean spectra are available: these are spectra that have been generated from a number of single observations of the same object. Epoch spectra, i.e. spectra consisting of one single observation, will become available in future releases.

GaiaXPy is a Python library to facilitate handling Gaia BP/RP spectra as distributed from the Gaia archive.

To learn more about the package click [here](https://gaiaxpy.readthedocs.io/en/latest/description.html).

You can also check the [homepage](https://gaia-dpci.github.io/GaiaXPy-website/) for documentation, tutorials, and resources.

## Licence
[BSD 3-Clause](https://github.com/gaia-dpci/GaiaXPy/blob/main/LICENCE)
